@@ -310,7 +310,7 @@ class EXAExecutionContext(default.DefaultExecutionContext):
                     ident = '?'
                     if value is None:
                         db_query = db_query.replace(ident, 'NULL', 1)
-                    elif isinstance(value, (int, long)):
+                    elif isinstance(value, six.integer_types):
                         db_query = db_query.replace(ident, str(value), 1)
                     elif isinstance(value, (float, Decimal)):
                         db_query = db_query.replace(ident, str(float(value)), 1)
@@ -363,6 +363,12 @@ class EXADialect(default.DefaultDialect):
         'SERIALIZABLE': 0
     }
 
+    def _get_default_schema_name(self, connection):
+        """
+        Using 'SYS' as default schema. Tables in 'SYS' are not reflectable!
+        """
+        return u"SYS"
+
     def normalize_name(self, name):
         """
         Converting EXASol case insensitive identifiers (upper case)
@@ -466,7 +472,10 @@ class EXADialect(default.DefaultDialect):
                 view_name=self.denormalize_name(view_name),
                 schema=self.denormalize_name(schema)).scalar()
         if rp:
-            return rp.decode(self.encoding)
+            if six.PY3:
+                return rp
+            else:
+                return rp.decode(self.encoding)
         else:
             return None
 
@@ -599,7 +608,7 @@ class EXADialect(default.DefaultDialect):
             local_cols.append(self.normalize_name(local_column))
             remote_cols.append(self.normalize_name(remote_column))
 
-        return fkeys.values()
+        return list(fkeys.values())
 
     @reflection.cache
     def get_indexes(self, connection, table_name, schema=None, **kw):
